# In-ICU Mortality Prediction

In-ICU mortality prediction can be used as a proxy signal for the patient's overall level of wellness and thus
effective monitoring needs. Likely due to the availability of this target, rather than the true possible
intervention surface offered by this task, it has been a widely used prediction target in the ML for
healthcare literature to date.
